<?php
/**
 * Coupon by User Role for WooCommerce - Core Class
 *
 * @version 1.3.0
 * @since   1.0.0
 *
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Coupon_by_User_Role_Core' ) ) :

class Alg_WC_Coupon_by_User_Role_Core {

	/**
	 * Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 *
	 * @todo    [maybe] init all options in constructor
	 * @todo    [maybe] use another error code (instead of `10000`) || maybe add option for customizable code
	 */
	function __construct() {
		if ( 'yes' === get_option( 'wpjup_wc_coupon_by_user_role_plugin_enabled', 'yes' ) ) {
			$this->coupon_error_code = 10000;
			add_filter( 'woocommerce_coupons_enabled', array( $this, 'coupons_enabled' ),          PHP_INT_MAX, 1 );
			add_filter( 'woocommerce_coupon_is_valid', array( $this, 'coupon_valid' ),             PHP_INT_MAX, 3 );
			add_filter( 'woocommerce_coupon_error',    array( $this, 'coupon_not_valid_message' ), PHP_INT_MAX, 3 );
			if ( 'yes' === get_option( 'wpjup_wc_coupon_by_user_role_invalid_per_coupon', 'no' ) ) {
				require_once( 'settings/class-alg-wc-coupon-by-user-role-meta-box.php' );
				add_filter( 'alg_wc_cbur_invalid_user_roles', array( $this, 'add_invalid_user_roles_per_coupon' ), 10, 2 );
			}
			add_shortcode( 'alg_wc_cbur_translate', array( $this, 'language_shortcode' ) );
		}
	}

	/**
	 * language_shortcode.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function language_shortcode( $atts, $content = '' ) {
		// E.g.: `[alg_wc_cbur_translate lang="DE" lang_text="Message for DE" not_lang_text="Message for other languages"]`
		if ( isset( $atts['lang_text'] ) && isset( $atts['not_lang_text'] ) && ! empty( $atts['lang'] ) ) {
			return ( ! defined( 'ICL_LANGUAGE_CODE' ) || ! in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['lang'] ) ) ) ) ) ?
				$atts['not_lang_text'] : $atts['lang_text'];
		}
		// E.g.: `[alg_wc_cbur_translate lang="DE"]Message for DE[/alg_wc_cbur_translate][alg_wc_cbur_translate lang="NL"]Message for NL[/alg_wc_cbur_translate][alg_wc_cbur_translate not_lang="DE,NL"]Message for other languages[/alg_wc_cbur_translate]`
		return (
			( ! empty( $atts['lang'] )     && ( ! defined( 'ICL_LANGUAGE_CODE' ) || ! in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['lang'] ) ) ) ) ) ) ||
			( ! empty( $atts['not_lang'] ) &&     defined( 'ICL_LANGUAGE_CODE' ) &&   in_array( strtolower( ICL_LANGUAGE_CODE ), array_map( 'trim', explode( ',', strtolower( $atts['not_lang'] ) ) ) ) )
		) ? '' : $content;
	}

	/**
	 * is_current_user_role.
	 *
	 * @version 1.3.0
	 * @since   1.3.0
	 */
	function is_current_user_role( $roles_to_check ) {
		$user_roles = $this->get_current_user_roles();
		$intersect  = array_intersect( $user_roles, $roles_to_check );
		return ( ! empty( $intersect ) );
	}

	/**
	 * get_current_user_roles.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function get_current_user_roles() {
		$user = wp_get_current_user();
		return ( ! empty( $user->roles ) && is_array( $user->roles ) ? array_map( array( $this, 'handle_guest_role' ), $user->roles ) : array( 'guest' ) );
	}

	/**
	 * handle_guest_role.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function handle_guest_role( $role ) {
		return ( '' != $role ? $role : 'guest' );
	}

	/**
	 * get_user_roles_options.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 *
	 * @todo    [maybe] `super_admin` (Super Admin)
	 */
	function get_user_roles_options() {
		return apply_filters( 'alg_wc_cbur_user_roles', array(
			'guest'         => __( 'Guest', 'coupon-by-user-role-for-woocommerce' ),
			'administrator' => __( 'Administrator', 'coupon-by-user-role-for-woocommerce' ),
			'editor'        => __( 'Editor', 'coupon-by-user-role-for-woocommerce' ),
			'author'        => __( 'Author', 'coupon-by-user-role-for-woocommerce' ),
			'contributor'   => __( 'Contributor', 'coupon-by-user-role-for-woocommerce' ),
			'subscriber'    => __( 'Subscriber', 'coupon-by-user-role-for-woocommerce' ),
			'customer'      => __( 'Customer', 'coupon-by-user-role-for-woocommerce' ),
			'shop_manager'  => __( 'Shop manager', 'coupon-by-user-role-for-woocommerce' ),
		) );
	}

	/**
	 * coupons_enabled.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function coupons_enabled( $is_enabled ) {
		$disabled_user_roles = get_option( 'wpjup_wc_coupon_by_user_role_disabled', array() );
		$disabled_user_roles = apply_filters( 'alg_wc_cbur_disabled_user_roles', ( ! empty( $disabled_user_roles ) ? $disabled_user_roles : array() ) );
		if ( ! empty( $disabled_user_roles ) && $this->is_current_user_role( $disabled_user_roles ) ) {
			return false;
		}
		return $is_enabled;
	}

	/**
	 * add_invalid_user_roles_per_coupon.
	 *
	 * @version 1.3.0
	 * @since   1.3.0
	 */
	function add_invalid_user_roles_per_coupon( $invalid_user_roles, $coupon ) {
		$invalid_user_roles_per_coupon = get_post_meta( $coupon->get_id(), '_' . 'wpjup_wc_coupon_by_user_role_invalid', true );
		if ( ! empty( $invalid_user_roles_per_coupon ) ) {
			$invalid_user_roles = array_merge( $invalid_user_roles, $invalid_user_roles_per_coupon );
		}
		return $invalid_user_roles;
	}

	/**
	 * coupon_valid.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function coupon_valid( $valid, $coupon, $discounts ) {
		$invalid_user_roles = get_option( 'wpjup_wc_coupon_by_user_role_invalid', array() );
		$invalid_user_roles = apply_filters( 'alg_wc_cbur_invalid_user_roles', ( ! empty( $invalid_user_roles ) ? $invalid_user_roles : array() ), $coupon );
		if ( ! empty( $invalid_user_roles ) && $this->is_current_user_role( $invalid_user_roles ) ) {
			throw new Exception( $this->get_coupon_not_valid_message( $coupon ), $this->coupon_error_code );
			return false;
		}
		return $valid;
	}

	/**
	 * coupon_not_valid_message.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function coupon_not_valid_message( $message, $code, $coupon ) {
		return ( $this->coupon_error_code == $code ? $this->get_coupon_not_valid_message( $coupon ) : $message );
	}

	/**
	 * get_coupon_not_valid_message.
	 *
	 * @version 1.3.0
	 * @since   1.3.0
	 *
	 * @todo    [maybe] add more placeholders?
	 */
	function get_coupon_not_valid_message( $coupon ) {
		$template     = get_option( 'wpjup_wc_coupon_by_user_role_invalid_message', __( 'Coupon is not valid for your user role.', 'coupon-by-user-role-for-woocommerce' ) );
		$placeholders = array(
			'%coupon_code%'   => $coupon->get_code(),
			'%coupon_amount%' => $coupon->get_amount(),
		);
		return do_shortcode( str_replace( array_keys( $placeholders ), $placeholders, $template ) );
	}

}

endif;

return new Alg_WC_Coupon_by_User_Role_Core();
