<?php
/**
 * Coupon by User Role for WooCommerce - Meta Box Settings
 *
 * @version 1.3.0
 * @since   1.1.0
 *
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Coupon_by_User_Role_Meta_Box' ) ) :

class Alg_WC_Coupon_by_User_Role_Meta_Box {

	/**
	 * Constructor.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function __construct() {
		add_action( 'add_meta_boxes',        array( $this, 'add_meta_box' ) );
		add_action( 'save_post_shop_coupon', array( $this, 'save_meta_box' ), PHP_INT_MAX, 2 );
	}

	/**
	 * get_meta_box_options.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function get_meta_box_options() {
		return array(
			array(
				'title'    => __( 'Invalidate for roles', 'coupon-by-user-role-for-woocommerce' ),
				'tooltip'  => __( 'Invalidate coupon for selected user roles.', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
			),
			array(
				'name'     => 'wpjup_wc_coupon_by_user_role_invalid',
				'default'  => array(),
				'type'     => 'select',
				'multiple' => true,
				'class'    => 'chosen_select',
				'options'  => alg_wc_coupon_by_user_role()->core->get_user_roles_options(),
				'css'      => 'width:100%;',
			),
		);
	}

	/**
	 * save_meta_box.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function save_meta_box( $post_id, $__post ) {
		// Check that we are saving with current metabox displayed.
		if ( ! isset( $_POST[ 'alg_wc_coupon_by_user_role_invalid_save_post' ] ) ) {
			return;
		}
		// Setup post (just in case...)
		global $post;
		$post = get_post( $post_id );
		setup_postdata( $post );
		// Save options
		foreach ( $this->get_meta_box_options() as $option ) {
			update_post_meta( $post_id, '_' . $option['name'], ( isset( $_POST[ $option['name'] ] ) ? wc_clean( $_POST[ $option['name'] ] ) : $option['default'] ) );
		}
		// Reset post
		wp_reset_postdata();
	}

	/**
	 * add_meta_box.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function add_meta_box() {
		add_meta_box(
			'alg-wc-coupon-by-user-role',
			__( 'Coupon by User Role', 'coupon-by-user-role-for-woocommerce' ),
			array( $this, 'create_meta_box' ),
			'shop_coupon',
			'side',
			'default'
		);
	}

	/**
	 * create_meta_box.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 *
	 * @todo    [maybe] `placeholder` for textarea
	 * @todo    [maybe] `class` for all types (now only for select)
	 * @todo    [maybe] `show_value` for all types (now only for multiple select)
	 */
	function create_meta_box() {
		$current_post_id = get_the_ID();
		$html = '';
		$html .= '<table class="widefat striped">';
		foreach ( $this->get_meta_box_options() as $option ) {
			$is_enabled = ( isset( $option['enabled'] ) && 'no' === $option['enabled'] ) ? false : true;
			if ( $is_enabled ) {
				if ( 'title' === $option['type'] ) {
					$maybe_tooltip = ( ! empty( $option['tooltip'] ) ? '<span>' . wc_help_tip( $option['tooltip'], true ) . '</span>' : '' );
					$html .= '<tr>';
					$html .= '<th colspan="3" style="' . ( isset( $option['css'] ) ? $option['css'] : 'text-align:left;font-weight:bold;' ) . '">' .
						$option['title'] . $maybe_tooltip . '</th>';
					$html .= '</tr>';
				} else {
					$custom_attributes = '';
					if ( get_post_meta( $current_post_id, '_' . $option['name'] ) ) {
						$option_value = get_post_meta( $current_post_id, '_' . $option['name'], true );
					} else {
						$option_value = ( isset( $option['default'] ) ) ? $option['default'] : '';
					}
					$css          = ( isset( $option['css'] )   ? $option['css']   : '' );
					$class        = ( isset( $option['class'] ) ? $option['class'] : '' );
					$show_value   = ( isset( $option['show_value'] ) && $option['show_value'] );
					$input_ending = '';
					if ( 'select' === $option['type'] ) {
						if ( ! empty( $option['multiple'] ) ) {
							$custom_attributes = ' multiple';
							$option_name       = $option['name'] . '[]';
						} else {
							$option_name       = $option['name'];
						}
						if ( isset( $option['custom_attributes'] ) ) {
							$custom_attributes .= ' ' . $option['custom_attributes'];
						}
						$options = '';
						foreach ( $option['options'] as $select_option_key => $select_option_value ) {
							$selected = '';
							if ( is_array( $option_value ) ) {
								foreach ( $option_value as $single_option_value ) {
									if ( '' != ( $selected = selected( $single_option_value, $select_option_key, false ) ) ) {
										break;
									}
								}
							} else {
								$selected = selected( $option_value, $select_option_key, false );
							}
							$options .= '<option value="' . $select_option_key . '" ' . $selected . '>' . $select_option_value . '</option>';
						}
					} elseif ( 'textarea' === $option['type'] ) {
						if ( '' === $css ) {
							$css = 'min-width:300px;';
						}
					} else {
						$input_ending = ' id="' . $option['name'] . '" name="' . $option['name'] . '" value="' . $option_value . '">';
						if ( isset( $option['custom_attributes'] ) ) {
							$input_ending = ' ' . $option['custom_attributes'] . $input_ending;
						}
						if ( isset( $option['placeholder'] ) ) {
							$input_ending = ' placeholder="' . $option['placeholder'] . '"' . $input_ending;
						}
					}
					switch ( $option['type'] ) {
						case 'price':
							$field_html = '<input style="' . $css . '" class="short wc_input_price" type="number" step="0.0001"' . $input_ending;
							break;
						case 'date':
							$field_html = '<input style="' . $css . '" class="input-text" display="date" type="text"' . $input_ending;
							break;
						case 'textarea':
							$field_html = '<textarea style="' . $css . '" id="' . $option['name'] . '" name="' . $option['name'] . '">' . $option_value . '</textarea>';
							break;
						case 'select':
							$field_html = '<select' . $custom_attributes . ' class="' . $class . '" style="' . $css . '" id="' . $option['name'] . '" name="' .
								$option_name . '">' . $options . '</select>' .
								( $show_value && ! empty( $option_value ) ? sprintf( '<em>' . __( 'Selected: %s.', 'coupon-by-user-role-for-woocommerce' ),
									implode( ', ', $option_value ) ) . '</em>' : '' );
							break;
						default:
							$field_html = '<input style="' . $css . '" class="short" type="' . $option['type'] . '"' . $input_ending;
							break;
					}
					$html .= '<tr>';
					$maybe_tooltip = ( isset( $option['tooltip'] ) && '' != $option['tooltip'] ) ?
						'<span style="float:right;">' . wc_help_tip( $option['tooltip'], true ) . '</span>' : '';
					if ( ! empty( $option['title'] ) ) {
						$html .= '<th style="text-align:left;width:25%;font-weight:bold;">' . $option['title'] . $maybe_tooltip . '</th>';
					}
					if ( isset( $option['desc'] ) && '' != $option['desc'] ) {
						$html .= '<td style="font-style:italic;width:25%;">' . $option['desc'] . '</td>';
					}
					$html .= '<td>' . $field_html . '</td>';
					$html .= '</tr>';
				}
			}
		}
		$html .= '</table>';
		$html .= '<input type="hidden" name="alg_wc_coupon_by_user_role_invalid_save_post" value="alg_wc_coupon_by_user_role_invalid_save_post">';
		echo $html;
	}

}

endif;

return new Alg_WC_Coupon_by_User_Role_Meta_Box();
