<?php
/**
 * Coupon by User Role for WooCommerce - General Section Settings
 *
 * @version 1.3.0
 * @since   1.0.0
 *
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Coupon_by_User_Role_Settings_General' ) ) :

class Alg_WC_Coupon_by_User_Role_Settings_General extends Alg_WC_Coupon_by_User_Role_Settings_Section {

	/**
	 * Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'coupon-by-user-role-for-woocommerce' );
		parent::__construct();
	}

	/**
	 * get_settings.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 *
	 * @todo    [next] Message: desc: `[alg_wc_cbur_translate]`
	 */
	function get_settings() {

		$plugin_settings = array(
			array(
				'title'    => __( 'Coupon by User Role Options', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_coupon_by_user_role_plugin_options',
			),
			array(
				'title'    => __( 'Coupon by User Role', 'coupon-by-user-role-for-woocommerce' ),
				'desc'     => '<strong>' . __( 'Enable plugin', 'coupon-by-user-role-for-woocommerce' ) . '</strong>',
				'desc_tip' => __( 'WooCommerce coupons by user roles.', 'coupon-by-user-role-for-woocommerce' ),
				'id'       => 'wpjup_wc_coupon_by_user_role_plugin_enabled',
				'default'  => 'yes',
				'type'     => 'checkbox',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_coupon_by_user_role_plugin_options',
			),
		);

		$all_coupons_settings = array(
			array(
				'title'    => __( 'All Coupons', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_coupon_by_user_role_all_coupons_options',
			),
			array(
				'title'    => __( 'Disable all coupons for selected user roles', 'coupon-by-user-role-for-woocommerce' ),
				'desc_tip' => __( 'This will disable all coupons for selected user roles. Coupons will be disabled completely, including coupon code input field on the cart and checkout pages.', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'multiselect',
				'class'    => 'chosen_select',
				'default'  => array(),
				'id'       => 'wpjup_wc_coupon_by_user_role_disabled',
				'options'  => alg_wc_coupon_by_user_role()->core->get_user_roles_options(),
			),
			array(
				'title'    => __( 'Invalidate all coupons for selected user roles', 'coupon-by-user-role-for-woocommerce' ),
				'desc_tip' => __( 'This will invalidate all coupons for selected user roles. Coupon code input field will still be available on the cart and checkout pages.', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'multiselect',
				'class'    => 'chosen_select',
				'default'  => array(),
				'id'       => 'wpjup_wc_coupon_by_user_role_invalid',
				'options'  => alg_wc_coupon_by_user_role()->core->get_user_roles_options(),
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_coupon_by_user_role_all_coupons_options',
			),
		);

		$per_coupon_settings = array(
			array(
				'title'    => __( 'Per Coupon', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_coupon_by_user_role_per_coupon_options',
			),
			array(
				'title'    => __( 'Invalidate per coupon', 'coupon-by-user-role-for-woocommerce' ),
				'desc'     => __( 'Enable', 'coupon-by-user-role-for-woocommerce' ),
				'desc_tip' => __( 'This will add "Coupon by User Role" meta box to each coupon\'s admin edit page.', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'checkbox',
				'default'  => 'no',
				'id'       => 'wpjup_wc_coupon_by_user_role_invalid_per_coupon',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_coupon_by_user_role_per_coupon_options',
			),
		);

		$message_settings = array(
			array(
				'title'    => __( 'Message', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_coupon_by_user_role_message_options',
			),
			array(
				'title'    => __( '"Coupon is not valid" message', 'coupon-by-user-role-for-woocommerce' ),
				'desc_tip' => __( 'Message that will be displayed for invalid coupons by user role.', 'coupon-by-user-role-for-woocommerce' ),
				'desc'     => sprintf( __( 'Available placeholders: %s.', 'coupon-by-user-role-for-woocommerce' ), '<code>' . implode( '</code>, <code>', array(
						'%coupon_code%',
						'%coupon_amount%',
					) ) . '</code>' ),
				'type'     => 'textarea',
				'default'  => __( 'Coupon is not valid for your user role.', 'coupon-by-user-role-for-woocommerce' ),
				'id'       => 'wpjup_wc_coupon_by_user_role_invalid_message',
				'css'      => 'width:100%;',
				'alg_wc_coupon_by_user_role_raw' => true,
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_coupon_by_user_role_message_options',
			),
		);

		$notes = apply_filters( 'alg_wc_cbur_settings', array(
			array(
				'title'    => __( 'Notes', 'coupon-by-user-role-for-woocommerce' ),
				'type'     => 'title',
				'id'       => 'alg_wc_coupon_by_user_role_notes',
				'desc'     => '<p style="background-color:white;padding:10px;">' . '<span class="dashicons dashicons-info" style="color:red;"></span> ' .
						sprintf( 'This plugin version includes "standard" user roles only: %s.',
							'<strong>' . implode( '</strong>, <strong>', alg_wc_coupon_by_user_role()->core->get_user_roles_options() ) . '</strong>' ) . ' ' .
						sprintf( 'If you need all your site\'s custom user roles to be included, you\'ll need to get %s plugin version.',
							'<a target="_blank" href="https://wpfactory.com/item/coupon-by-user-role-for-woocommerce/">' . 'Coupon by User Role for WooCommerce Pro' . '</a>' ) .
					'</p>',
			),
			array(
				'type'     => 'sectionend',
				'id'       => 'alg_wc_coupon_by_user_role_notes',
			),
		) );

		return array_merge( $plugin_settings, $all_coupons_settings, $per_coupon_settings, $message_settings, ( ! empty( $notes ) ? $notes : array() ) );
	}

}

endif;

return new Alg_WC_Coupon_by_User_Role_Settings_General();
