<?php
/**
 * Coupon by User Role for WooCommerce - Settings
 *
 * @version 1.3.0
 * @since   1.0.0
 *
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Coupon_by_User_Role_Settings' ) ) :

class Alg_WC_Coupon_by_User_Role_Settings extends WC_Settings_Page {

	/**
	 * Constructor.
	 *
	 * @version 1.3.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id    = 'alg_wc_coupon_by_user_role';
		$this->label = __( 'Coupon by User Role', 'coupon-by-user-role-for-woocommerce' );
		parent::__construct();
		// Filters
		add_filter( 'woocommerce_admin_settings_sanitize_option', array( $this, 'maybe_unclean_field' ), PHP_INT_MAX, 3 );
		// Sections
		require_once( 'class-alg-wc-coupon-by-user-role-settings-section.php' );
		require_once( 'class-alg-wc-coupon-by-user-role-settings-general.php' );
	}

	/**
	 * maybe_unclean_field.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 *
	 * @todo    [later] find better solution
	 */
	function maybe_unclean_field( $value, $option, $raw_value ) {
		return ( isset( $option['alg_wc_coupon_by_user_role_raw'] ) && $option['alg_wc_coupon_by_user_role_raw'] ? $raw_value : $value );
	}

	/**
	 * get_settings.
	 *
	 * @version 1.2.0
	 * @since   1.0.0
	 */
	function get_settings() {
		global $current_section;
		return array_merge( apply_filters( 'woocommerce_get_settings_' . $this->id . '_' . $current_section, array() ), array(
			array(
				'title'     => __( 'Reset Settings', 'coupon-by-user-role-for-woocommerce' ),
				'type'      => 'title',
				'id'        => $this->id . '_' . $current_section . '_reset_options',
			),
			array(
				'title'     => __( 'Reset section settings', 'coupon-by-user-role-for-woocommerce' ),
				'desc'      => '<strong>' . __( 'Reset', 'coupon-by-user-role-for-woocommerce' ) . '</strong>',
				'desc_tip'  => __( 'Check the box and save changes to reset.', 'coupon-by-user-role-for-woocommerce' ),
				'id'        => $this->id . '_' . $current_section . '_reset',
				'default'   => 'no',
				'type'      => 'checkbox',
			),
			array(
				'type'      => 'sectionend',
				'id'        => $this->id . '_' . $current_section . '_reset_options',
			),
		) );
	}

	/**
	 * maybe_reset_settings.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function maybe_reset_settings() {
		global $current_section;
		if ( 'yes' === get_option( $this->id . '_' . $current_section . '_reset', 'no' ) ) {
			foreach ( $this->get_settings() as $value ) {
				if ( isset( $value['id'] ) ) {
					$id = explode( '[', $value['id'] );
					delete_option( $id[0] );
				}
			}
			add_action( 'admin_notices', array( $this, 'admin_notice_settings_reset' ) );
		}
	}


	/**
	 * admin_notice_settings_reset.
	 *
	 * @version 1.1.0
	 * @since   1.1.0
	 */
	function admin_notice_settings_reset() {
		echo '<div class="notice notice-warning is-dismissible"><p><strong>' .
			__( 'Your settings have been reset.', 'coupon-by-user-role-for-woocommerce' ) . '</strong></p></div>';
	}

	/**
	 * Save settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function save() {
		parent::save();
		$this->maybe_reset_settings();
	}

}

endif;

return new Alg_WC_Coupon_by_User_Role_Settings();
